@@ -4,12 +4,13 @@
 package config_test
 
 import (
-	"github.com/stretchr/testify/require"
-	"github.com/vmware-tanzu/carvel-kapp/pkg/kapp/config"
-	ctldiff "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/diff"
-	ctlres "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resources"
 	"strings"
 	"testing"
+
+	"carvel.dev/kapp/pkg/kapp/config"
+	ctldiff "carvel.dev/kapp/pkg/kapp/diff"
+	ctlres "carvel.dev/kapp/pkg/kapp/resources"
+	"github.com/stretchr/testify/require"
 )
 
 func TestDefaultTemplateRules(t *testing.T) {
