@@ -7,7 +7,7 @@ import (
 	"fmt"
 	"strings"
 
-	ctlres "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resources"
+	ctlres "carvel.dev/kapp/pkg/kapp/resources"
 )
 
 type ResourceTypes struct {
